<?php
defined('SYSPATH') or die('No direct access allowed.');

if ($error) {
	$csv = false;
	echo "Couldn't generate your archived log search: \n";
	foreach ($error as $err) {
		$csv[] = $err;
	}
	echo implode(", ", $csv)."\n";
}

if($query !== false) {
	$date_format = date::date_format();
	$FAC_VALUES = LogMessage_Model::$FAC_VALUES;
	$SEV_VALUES = LogMessage_Model::$SEV_VALUES;

	$column_defs = array(
		'ip' => array(
			'name' => _('Source IP address')
		),
		'rtime' => array(
			'name' => _('Receive time'),
			'format' => function($v) use ($date_format) {
				return date($date_format, $v);
			}
		),
		'facility' => array(
			'name' => _('Facility'),
			'format' => function($v) use ($FAC_VALUES) {
				if(!isset($FAC_VALUES[$v]))
					return "Unknown ($v)";
				return $FAC_VALUES[$v];
			}
		),
		'severity' => array(
			'name' => _('Severity'),
			'format' => function($v) use ($SEV_VALUES) {
				if(!isset($SEV_VALUES[$v]))
					return "Unknown ($v)";
				return $SEV_VALUES[$v];
			}
		),
		'mtime' => array(
			'name' => _('Message time'),
			'format' => function($v) use ($date_format) {
				return date($date_format, $v);
			}
		),
		'host' => array(
			'name' => _('Host')
		),
		'ident' => array(
			'name' => _('Ident')
		),
		'pid' => array(
			'name' => _('PID')
		),
		'event' => array(
			'name' => _('Event')
		),
		'msg' => array(
			'name' => _('Message')
		),
	);

	$col_formatters = array();
	$csv = false;
	$pdf_hidden = Kohana::config('logger.pdf_columns');
	foreach ($columns as $col) {
		if(isset($column_defs[$col])) {
			$formatter =& $column_defs[$col];
			$name = $formatter['name'];
			if(!isset($formatter['format'])) {
				$formatter['format'] = 'htmlentities';
			}

			if (!in_array($col, $pdf_hidden))
				$formatter['hide_in_pdf'] = true;

			$col_formatters[] = $formatter;

			if(!isset($formatter['hide_in_pdf'])) {
				$csv[] = '"' . htmlentities($name) . '"';
			}
		} else {
			$col_formatters[] = null;
		}
	}
	echo implode(', ', $csv)."\n";

	$csv = false;
	if (!isset($paths)) {
		foreach ($set->it($columns, array('rtime asc')) as $logline) {

			$csv = false;
			foreach ($logline->export() as $key => $value) {
				if (isset($column_defs[$key])) {
					if (isset($column_defs[$key]['format']))
						$format_val = $column_defs[$key]['format']($value);
					else
						$format_val = htmlentities($value);
					if(!isset($column_defs[$key]['hide_in_pdf'])) {
						$csv[] = '"' . $format_val . '"';
					}
				}
			}
			echo implode(",", $csv)."\n";
		}
	}
	else {
		$binary = Kohana::config('logger.logfilter.path');

		$descspec = array (0 => array ('pipe','r'),1 => array ('pipe','w'),
			2 => array ('pipe','w'));

		$cmd = $binary;
		foreach($paths as $path) {
			$cmd .=  ' --path ' . escapeshellarg($path);
		}
		$cmd .= ' interactive';
		$cmd .= ' --begin ' . escapeshellarg($start_time);
		$cmd .= ' --end ' . escapeshellarg($end_time);
		$cmd .= ' ' . escapeshellarg($query);

		$proc = proc_open($cmd, $descspec, $pipes);

		if ($proc !== false) {
			while (false !== ($line = fgets($pipes[1]))) {
				set_time_limit(30);
				$logline = json_decode($line);
				if (is_array($logline)) {

					$csv = false;
					foreach ($logline as $i => $value) {
						if ($col_formatters[$i] != null) {
							$format_val = $col_formatters[$i]['format']($value);
							if(!isset($col_formatters[$i]['hide_in_pdf'])) {
								$csv[] = '"' . $format_val . '"';
							}
						}
					}
					echo implode(",", $csv)."\n";
				} else {
					$csv[] = '"ERROR: can\'t parse line: "' . htmlentities($line) . '"';
					echo implode(",", $csv)."\n";
				}
			}
		}

	}
}
